@@ -1470,6 +1470,13 @@ class Wrapper:
         else:
             return actual_worktime / 3600 / 1000
 
+    @staticmethod
+    def _get_working_description_from_labor(labor: Dict[str, Any]) -> Optional[str]:
+        working_time_by_user = labor["values"]["working_time_by_user"]
+        if working_time_by_user is None:
+            return None
+        return working_time_by_user.get("description")
+
     def get_labor_control_worktime(
         self,
         organization_id: Optional[str] = None,
@@ -1491,6 +1498,7 @@ class Wrapper:
         def _to_new_data(labor: Dict[str, Any]) -> Dict[str, Any]:
             labor["actual_worktime"] = self._get_actual_worktime_hour_from_labor(labor)
             labor["plan_worktime"] = self._get_plan_worktime_hour_from_labor(labor)
+            labor["working_description"] = self._get_working_description_from_labor(labor)
             labor.pop("values", None)
             return labor
 
@@ -1498,8 +1506,8 @@ class Wrapper:
             "organization_id": organization_id,
             "project_id": project_id,
             "account_id": account_id,
-            "from_date": from_date,
-            "to_date": to_date,
+            "from": from_date,
+            "to": to_date,
         }
         labor_list, _ = self.api.get_labor_control(query_params)
         return [_to_new_data(e) for e in labor_list]
